@@ -2,7 +2,9 @@
 import os
 from pathlib import Path
 
-__version__ = "0.6.1"
+from ansys_sphinx_theme.latex import generate_404  # noqa: F401
+
+__version__ = "0.8.2"
 
 # get location of this directory
 _this_path = os.path.dirname(os.path.realpath(__file__))
@@ -20,7 +22,6 @@ ansys_logo_black = os.path.join(_this_path, "static", "ansys_logo_black_cropped.
 page_404 = os.path.join(_this_path, "static", "404.rst")
 
 html_logo = pyansys_logo_black
-
 CSS_FILENAME = "ansys_sphinx_theme.css"
 
 
@@ -29,6 +30,14 @@ def get_html_theme_path():
     return Path(__file__).parents[0].absolute()
 
 
+def get_version_match(semver):
+    """Evaluate the version match for the multi-documentation."""
+    if semver.endswith("dev0"):
+        return "dev"
+    major, minor, _ = semver.split(".")
+    return ".".join([major, minor])
+
+
 def setup(app):
     """Connect to the sphinx theme app."""
     theme_path = get_html_theme_path()
